# package_name

Description. 
The package package_name is used to:
	Processing:
	- Histogram matching
	- Structural similarity
	- Resize image
	Utils:
	- Read image
	- Save image
	- Plot image
	- Plot result
	- Plot histogram

## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install image_processing_

```bash
pip install image_processing_clpe
```


## Author
Carlos_Eduardo

## License
[MIT](https://choosealicense.com/licenses/mit/)